##  Deleting Fact Sheets
Fact sheets can not be deleted directly. To delete a fact sheet you need to archive it first. When a fact sheet is archived, it is removed from the inventory but can still be accessed for up to 90 days. To know how, see [Viewing and Recovering the Archived Fact Sheets](https://help.sap.com/docs/leanix/ea/archiving-deleting-and-recovering-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758bfdf7a4410148e40d4c9a8ea607a__viewing_and_recovering_the_archived_fact_sheets) During this retention period, you can also recover archived fact sheets at any time if needed. After the retention period, the archived fact sheet is automatically and permanently deleted with no possibility of recovery.
